@@ -3,3 +3,5 @@ const char *TableGetMonth (int code);
 const char *TableGetLang (UBYTE code);
 void        TablePrintLang (void);
 const char *TableGetCountry (UWORD code);
+const char *TableGetOccupation (UWORD code);
+const char *TableGetInterest (UWORD code);
