@@ -1,9 +1,12 @@
+/* $Id: file_util.c,v 1.19 2001/06/17 21:56:26 kuhlmann Exp $ */
+
 #include "micq.h"
 #include "buildmark.h"
 #include "util_ui.h"
 #include "file_util.h"
 #include "tabs.h"
 #include "util.h"
+#include "sendmsg.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -12,16 +15,18 @@
 #include <string.h>
 #include <ctype.h>
 #include <errno.h>
-#include <time.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #ifdef _WIN32
 #include <io.h>
 #define S_IRUSR        _S_IREAD
 #define S_IWUSR        _S_IWRITE
 #else
-#include <sys/time.h>
 #include <netinet/in.h>
 #include <termios.h>
 #ifndef __BEOS__
@@ -29,19 +34,16 @@
 #endif
 #endif
 
-#ifdef UNIX
-#include <unistd.h>
-#endif
-
-
 /****/
 
 #define      ADD_STRING(a,b)     else if (!strcasecmp (tmp, a))   \
                                        snprintf (b, sizeof (b), "%s", strtok (NULL, " \n\t"))
+#define      ADD_CMD(a,b)        else if (!strcasecmp (tmp, a))   \
+                                       snprintf (b, sizeof (b), "%s", strtok (NULL, "\n\t"))
 
 static char rcfile[256];
 
-void Set_rcfile (char *name)
+void Set_rcfile (const char *name)
 {
     char *path = 0;
     char *home;
@@ -57,7 +59,6 @@ void Set_rcfile (char *name)
         path = "PROGDIR:";
 #endif
 
-#ifdef UNIX
         home = getenv ("HOME");
         if (home || !path)
         {
@@ -68,7 +69,6 @@ void Set_rcfile (char *name)
             if (path[strlen (path) - 1] != '/')
                 strcat (path, "/");
         }
-#endif
 
         strcpy (rcfile, path);
         strcat (rcfile, ".micqrc");
@@ -77,7 +77,7 @@ void Set_rcfile (char *name)
     else
     {
         strncpy (rcfile, name, 256);
-        name[255] = 0;
+        rcfile[255] = 0;
     }
 }
 
@@ -105,55 +105,55 @@ static void Initalize_RC_File (void)
 
     away_time = default_away_time;
 
-    M_print ("Enter UIN or 0 for new UIN: #");
+    M_print ("%s ", i18n (88, "Enter UIN or 0 for new UIN:"));
     fflush (stdout);
     scanf ("%ld", &UIN);
   password_entry:
-    M_print ("Enter password : ");
+    M_print ("%s ", i18n (63, "Enter password:"));
     fflush (stdout);
-    Echo_Off ();
     memset (passwd, 0, sizeof (passwd));
+    Echo_Off ();
     M_fdnreadln (STDIN, passwd, sizeof (passwd));
     Echo_On ();
     if (UIN == 0)
     {
         if (0 == passwd[0])
         {
-            M_print ("\nMust enter password!\n");
+            M_print ("\n%s\n", i18n (91, "Must enter password!"));
             goto password_entry;
         }
-        M_print ("\nReenter password to verify: ");
+        M_print ("\n%s ", i18n (92, "Reenter password to verify:"));
         fflush (stdout);
-        Echo_Off ();
         memset (passwd2, 0, sizeof (passwd2));
+        Echo_Off ();
         M_fdnreadln (STDIN, passwd2, sizeof (passwd));
         Echo_On ();
         if (strcmp (passwd, passwd2))
         {
-            M_print ("\nPasswords did not match reenter\n");
+            M_print ("\n%s\n", i18n (93, "Passwords did not match - please reenter."));
             goto password_entry;
         }
         Init_New_User ();
     }
 
 /* SOCKS5 stuff begin */
-    M_print ("\nSOCKS5 server hostname or IP (type 0 if you don't want to use this) : ");
+    M_print ("\n%s ", i18n (94, "SOCKS5 server hostname or IP (type 0 if you don't want to use this):"));
     fflush (stdout);
     scanf ("%s", s5Host);
     if (strlen (s5Host) > 1)
     {
         s5Use = 1;
-        M_print ("SOCKS5 port (in general 1080) : ");
+        M_print ("%s ", i18n (95, "SOCKS5 port (in general 1080):"));
         fflush (stdout);
         scanf ("%hu", &s5Port);
 
-        M_print ("SOCKS5 username (type 0 if you don't need authentification) : ");
+        M_print ("%s ", i18n (96, "SOCKS5 username (type 0 if you don't need authentification):"));
         fflush (stdout);
         scanf ("%s", s5Name);
         if (strlen (s5Name) > 1)
         {
             s5Auth = 1;
-            M_print ("SOCKS5 password : ");
+            M_print ("%s ", i18n (97, "SOCKS5 password:"));
             fflush (stdout);
             scanf ("%s", s5Pass);
         }
@@ -252,6 +252,7 @@ static void Read_RC_File (FD_T rcf)
 {
     char buf[450];
     char *tmp;
+    char *p;
     int i;
     UDWORD tmp_uin;
     char *tab_nick_spool[TAB_SLOTS];
@@ -313,7 +314,7 @@ static void Read_RC_File (FD_T rcf)
     Contact_List = FALSE;
     for (i = 1; !Contact_List || buf == 0; i++)
     {
-/*      M_print( "Starting Line " SERVCOL " %d" NOCOL "\n", i );*/
+/*      M_print( "Starting Line " COLSERV " %d" COLNONE "\n", i );*/
         M_fdnreadln (rcf, buf, sizeof (buf));
         if ((buf[0] != '#') && (buf[0] != 0))
         {
@@ -384,8 +385,7 @@ static void Read_RC_File (FD_T rcf)
             else if (!strcasecmp (tmp, "No_Log"))
             {
                 LogType = 0;
-                M_print (CONTACTCOL
-                         "\"No_Log\" is deprecated.\nUse \"LogType 0\" Instead.\n" NOCOL);
+                M_print (i18n (98, COLCONTACT "\"No_Log\" is deprecated.\nUse \"LogType 0\" Instead.\n" COLNONE));
                 Logging = FALSE;
             }
             else if (!strcasecmp (tmp, "No_Color"))
@@ -420,11 +420,11 @@ static void Read_RC_File (FD_T rcf)
             {
                 auto_resp = TRUE;
             }
-            ADD_STRING ("auto_rep_str_away", auto_rep_str_away);
-            ADD_STRING ("auto_rep_str_na", auto_rep_str_na);
-            ADD_STRING ("auto_rep_str_dnd", auto_rep_str_dnd);
-            ADD_STRING ("auto_rep_str_occ", auto_rep_str_occ);
-            ADD_STRING ("auto_rep_str_inv", auto_rep_str_inv);
+            ADD_CMD ("auto_rep_str_away", auto_rep_str_away);
+            ADD_CMD ("auto_rep_str_na", auto_rep_str_na);
+            ADD_CMD ("auto_rep_str_dnd", auto_rep_str_dnd);
+            ADD_CMD ("auto_rep_str_occ", auto_rep_str_occ);
+            ADD_CMD ("auto_rep_str_inv", auto_rep_str_inv);
             else if (!strcasecmp (tmp, "LogDir"))
             {
                 Set_Log_Dir (strtok (NULL, "\n"));
@@ -497,7 +497,7 @@ static void Read_RC_File (FD_T rcf)
             }
             else
             {
-                M_print (SERVCOL "Unrecognized command in rc file : %s, ignored." NOCOL "\n", tmp);
+                M_print (i18n (188, COLSERV "Unrecognized command in rc file '%s', ignored." COLNONE "\n"), tmp);
             }
         }
     }
@@ -505,93 +505,101 @@ static void Read_RC_File (FD_T rcf)
     {
         if (Num_Contacts == MAX_CONTACTS)
             break;
-        if ((buf[0] != '#') && (buf[0] != 0))
+
+        p = buf;
+
+        while (*p == ' ')
+            p++;
+
+        if (!*p || *p == '#' )
+            continue;
+
+        if (isdigit ((int) *p))
         {
-            if (isdigit ((int) buf[0]))
-            {
-                Contacts[Num_Contacts].uin = atoi (strtok (buf, " "));
-                Contacts[Num_Contacts].status = STATUS_OFFLINE;
-                Contacts[Num_Contacts].last_time = -1L;
-                Contacts[Num_Contacts].current_ip[0] = 0xff;
-                Contacts[Num_Contacts].current_ip[1] = 0xff;
-                Contacts[Num_Contacts].current_ip[2] = 0xff;
-                Contacts[Num_Contacts].current_ip[3] = 0xff;
-                tmp = strtok (NULL, "");
-                if (tmp != NULL)
-                    memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
-                else
-                    Contacts[Num_Contacts].nick[0] = 0;
-                if (Contacts[Num_Contacts].nick[19] != 0)
-                    Contacts[Num_Contacts].nick[19] = 0;
-                if (Verbose > 2)
-                    M_print ("%ld = %s\n", Contacts[Num_Contacts].uin, Contacts[Num_Contacts].nick);
-                Contacts[Num_Contacts].vis_list = FALSE;
-                Num_Contacts++;
-            }
-            else if (buf[0] == '*')
-            {
-                Contacts[Num_Contacts].uin = atoi (strtok (&buf[1], " "));
-                Contacts[Num_Contacts].status = STATUS_OFFLINE;
-                Contacts[Num_Contacts].last_time = -1L;
-                Contacts[Num_Contacts].current_ip[0] = 0xff;
-                Contacts[Num_Contacts].current_ip[1] = 0xff;
-                Contacts[Num_Contacts].current_ip[2] = 0xff;
-                Contacts[Num_Contacts].current_ip[3] = 0xff;
-                tmp = strtok (NULL, "");
-                if (tmp != NULL)
-                    memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
-                else
-                    Contacts[Num_Contacts].nick[0] = 0;
-                if (Contacts[Num_Contacts].nick[19] != 0)
-                    Contacts[Num_Contacts].nick[19] = 0;
-                if (Verbose > 2)
-                    M_print ("%ld = %s\n", Contacts[Num_Contacts].uin, Contacts[Num_Contacts].nick);
-                Contacts[Num_Contacts].invis_list = FALSE;
-                Contacts[Num_Contacts].vis_list = TRUE;
-                Num_Contacts++;
-            }
-            else if (buf[0] == '~')
-            {
-                Contacts[Num_Contacts].uin = atoi (strtok (&buf[1], " "));
-                Contacts[Num_Contacts].status = STATUS_OFFLINE;
-                Contacts[Num_Contacts].last_time = -1L;
-                Contacts[Num_Contacts].current_ip[0] = 0xff;
-                Contacts[Num_Contacts].current_ip[1] = 0xff;
-                Contacts[Num_Contacts].current_ip[2] = 0xff;
-                Contacts[Num_Contacts].current_ip[3] = 0xff;
-                tmp = strtok (NULL, "");
-                if (tmp != NULL)
-                    memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
-                else
-                    Contacts[Num_Contacts].nick[0] = 0;
-                if (Contacts[Num_Contacts].nick[19] != 0)
-                    Contacts[Num_Contacts].nick[19] = 0;
-                if (Verbose > 2)
-                    M_print ("%ld = %s\n", Contacts[Num_Contacts].uin, Contacts[Num_Contacts].nick);
-                Contacts[Num_Contacts].invis_list = TRUE;
-                Contacts[Num_Contacts].vis_list = FALSE;
-                Num_Contacts++;
-            }
+            Contacts[Num_Contacts].uin = atoi (strtok (p, " "));
+            Contacts[Num_Contacts].status = STATUS_OFFLINE;
+            Contacts[Num_Contacts].last_time = -1L;
+            Contacts[Num_Contacts].current_ip[0] = 0xff;
+            Contacts[Num_Contacts].current_ip[1] = 0xff;
+            Contacts[Num_Contacts].current_ip[2] = 0xff;
+            Contacts[Num_Contacts].current_ip[3] = 0xff;
+            tmp = strtok (NULL, "");
+            if (tmp != NULL)
+                memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
             else
+                Contacts[Num_Contacts].nick[0] = 0;
+            if (Contacts[Num_Contacts].nick[19] != 0)
+                Contacts[Num_Contacts].nick[19] = 0;
+            if (Verbose > 2)
+                M_print ("%ld = %s\n", Contacts[Num_Contacts].uin, Contacts[Num_Contacts].nick);
+            Contacts[Num_Contacts].vis_list = FALSE;
+            Num_Contacts++;
+        }
+        else if (*p == '*')
+        {
+            for (p++; *p == ' '; p++) ;
+            Contacts[Num_Contacts].uin = atoi (strtok (p, " "));
+            Contacts[Num_Contacts].status = STATUS_OFFLINE;
+            Contacts[Num_Contacts].last_time = -1L;
+            Contacts[Num_Contacts].current_ip[0] = 0xff;
+            Contacts[Num_Contacts].current_ip[1] = 0xff;
+            Contacts[Num_Contacts].current_ip[2] = 0xff;
+            Contacts[Num_Contacts].current_ip[3] = 0xff;
+            tmp = strtok (NULL, "");
+            if (tmp != NULL)
+                memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
+            else
+                Contacts[Num_Contacts].nick[0] = 0;
+            if (Contacts[Num_Contacts].nick[19] != 0)
+                Contacts[Num_Contacts].nick[19] = 0;
+            if (Verbose > 2)
+                M_print ("%ld = %s\n", Contacts[Num_Contacts].uin, Contacts[Num_Contacts].nick);
+            Contacts[Num_Contacts].invis_list = FALSE;
+            Contacts[Num_Contacts].vis_list = TRUE;
+            Num_Contacts++;
+        }
+        else if (*p == '~')
+        {
+            for (p++; *p == ' '; p++) ;
+            Contacts[Num_Contacts].uin = atoi (strtok (p, " "));
+            Contacts[Num_Contacts].status = STATUS_OFFLINE;
+            Contacts[Num_Contacts].last_time = -1L;
+            Contacts[Num_Contacts].current_ip[0] = 0xff;
+            Contacts[Num_Contacts].current_ip[1] = 0xff;
+            Contacts[Num_Contacts].current_ip[2] = 0xff;
+            Contacts[Num_Contacts].current_ip[3] = 0xff;
+            tmp = strtok (NULL, "");
+            if (tmp != NULL)
+                memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
+            else
+                Contacts[Num_Contacts].nick[0] = 0;
+            if (Contacts[Num_Contacts].nick[19] != 0)
+                Contacts[Num_Contacts].nick[19] = 0;
+            if (Verbose > 2)
+                M_print ("%ld = %s\n", Contacts[Num_Contacts].uin, Contacts[Num_Contacts].nick);
+            Contacts[Num_Contacts].invis_list = TRUE;
+            Contacts[Num_Contacts].vis_list = FALSE;
+            Num_Contacts++;
+        }
+        else
+        {
+            tmp_uin = Contacts[Num_Contacts - 1].uin;
+            tmp = strtok (p, ", \t");     /* aliases may not have spaces */
+            for (; tmp != NULL; Num_Contacts++)
             {
-                tmp_uin = Contacts[Num_Contacts - 1].uin;
-                tmp = strtok (buf, ", \t");     /* aliases may not have spaces */
-                for (; tmp != NULL; Num_Contacts++)
-                {
-                    Contacts[Num_Contacts].uin = -tmp_uin;
-                    Contacts[Num_Contacts].status = STATUS_OFFLINE;
-                    Contacts[Num_Contacts].last_time = -1L;
-                    Contacts[Num_Contacts].current_ip[0] = 0xff;
-                    Contacts[Num_Contacts].current_ip[1] = 0xff;
-                    Contacts[Num_Contacts].current_ip[2] = 0xff;
-                    Contacts[Num_Contacts].current_ip[3] = 0xff;
-                    Contacts[Num_Contacts].port = 0;
-                    Contacts[Num_Contacts].sok = (SOK_T) - 1L;
-                    Contacts[Num_Contacts].invis_list = FALSE;
-                    Contacts[Num_Contacts].vis_list = FALSE;
-                    memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
-                    tmp = strtok (NULL, ", \t");
-                }
+                Contacts[Num_Contacts].uin = -tmp_uin;
+                Contacts[Num_Contacts].status = STATUS_OFFLINE;
+                Contacts[Num_Contacts].last_time = -1L;
+                Contacts[Num_Contacts].current_ip[0] = 0xff;
+                Contacts[Num_Contacts].current_ip[1] = 0xff;
+                Contacts[Num_Contacts].current_ip[2] = 0xff;
+                Contacts[Num_Contacts].current_ip[3] = 0xff;
+                Contacts[Num_Contacts].port = 0;
+                Contacts[Num_Contacts].sok = (SOK_T) - 1L;
+                Contacts[Num_Contacts].invis_list = FALSE;
+                Contacts[Num_Contacts].vis_list = FALSE;
+                memcpy (Contacts[Num_Contacts].nick, tmp, sizeof (Contacts->nick));
+                tmp = strtok (NULL, ", \t");
             }
         }
     }
@@ -684,14 +692,14 @@ static void Read_RC_File (FD_T rcf)
 
     if (Verbose)
     {
-        M_print ("UIN = %ld\n", UIN);
-        M_print ("port = %ld\n", remote_port);
-        M_print ("passwd = %s\n", passwd);
-        M_print ("server = %s\n", server);
-        M_print ("status = %ld\n", set_status);
-        M_print ("# of contacts = %d\n", Num_Contacts);
-        M_print ("UIN of contact[0] = %ld\n", Contacts[0].uin);
-        M_print ("Message_cmd = %s\n", message_cmd);
+        M_print (i18n (189, "UIN = %ld\n"), UIN);
+        M_print (i18n (190, "port = %ld\n"), remote_port);
+        M_print (i18n (191, "passwd = %s\n"), passwd);
+        M_print (i18n (192, "server = %s\n"), server);
+        M_print (i18n (193, "status = %ld\n"), set_status);
+        M_print (i18n (194, "# of contacts = %d\n"), Num_Contacts);
+        M_print (i18n (195, "UIN of contact[0] = %ld\n"), Contacts[0].uin);
+        M_print (i18n (196, "Message_cmd = %s\n"), message_cmd);
     }
     if (UIN == 0)
     {
@@ -709,9 +717,9 @@ int Save_RC ()
 {
     FD_T rcf;
     time_t t;
-    int i, j;
+    int i, j, k;
 
-    rcf = open (rcfile, O_RDWR);
+    rcf = open (rcfile, O_WRONLY | O_CREAT | O_TRUNC);
     if (rcf == -1)
         return -1;
     M_fdprint (rcf, "# This file was generated by Micq of %s %s\n", __TIME__, __DATE__);
@@ -771,6 +779,9 @@ int Save_RC ()
 
     M_fdprint (rcf, "LogType %d\n\n", LogType);
 
+    M_fdprint (rcf, "# Define to a program which is executed to play sound when a message is received.\n");
+    M_fdprint (rcf, "sound %s%s\n\n", Sound_Str, Sound == SOUND_OFF ? "" : "\nNo_Sound");
+
     if (Color)
         M_fdprint (rcf, "#No_Color\n");
     else
@@ -839,6 +850,7 @@ int Save_RC ()
     M_fdprint (rcf, "alter_cmd %s\n", alter_cmd);
     M_fdprint (rcf, "msga_cmd %s\n", msga_cmd);
     M_fdprint (rcf, "url_cmd %s\n", url_cmd);
+    M_fdprint (rcf, "sound_cmd %s\n", sound_cmd);
     M_fdprint (rcf, "update_cmd %s\n", update_cmd);
     M_fdprint (rcf, "about_cmd %s\n", about_cmd);
 
@@ -862,24 +874,22 @@ int Save_RC ()
     {
         if (!(Contacts[i].uin & 0x80000000L))
         {
-            if (Contacts[i].vis_list)
-            {
-                M_fdprint (rcf, "*");
-            }
-            if (Contacts[i].invis_list)
-            {
-                M_fdprint (rcf, "~");
-            }
-            M_fdprint (rcf, "%d %s\n", Contacts[i].uin, Contacts[i].nick);
+            M_fdprint (rcf, Contacts[i].vis_list ? "*" : Contacts[i].invis_list ? "~" : " ");
+            M_fdprint (rcf, "%9d %s\n", Contacts[i].uin, Contacts[i].nick);
 /*     M_fdprint( rcf, "#Begining of aliases for %s\n", Contacts[i].nick ); */
+            k = 0;
             for (j = 0; j < Num_Contacts; j++)
             {
                 if (Contacts[j].uin == -Contacts[i].uin)
                 {
-                    M_fdprint (rcf, "%s ", Contacts[j].nick);
+                    if (k)
+                        M_fdprint (rcf, " ");
+                    M_fdprint (rcf, "%s", Contacts[j].nick);
+                    k++;
                 }
             }
-            M_fdprint (rcf, "\n");
+            if (k)
+                M_fdprint (rcf, "\n");
 /*     M_fdprint( rcf, "\n#End of aliases for %s\n", Contacts[i].nick ); */
         }
     }
