@@ -1,13 +1,19 @@
+/* $Id: micq.c,v 1.19 2001/06/17 21:56:27 kuhlmann Exp $ */
+
 #include "micq.h"
 #include "util_ui.h"
 #include "file_util.h"
 #include "util.h"
 #include "buildmark.h"
+#include "sendmsg.h"
+#include "network.h"
+#include "ui.h"
+#include "icq_response.h"
+#include "server.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <fcntl.h>
-#include <time.h>
 #include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
@@ -17,7 +23,6 @@
 #include <conio.h>
 #include <io.h>
 #include <winsock2.h>
-#include <time.h>
 #else
 #include <sys/types.h>
 #include <unistd.h>
@@ -29,7 +34,6 @@
 #include <arpa/inet.h>
 #endif
 #include <netdb.h>
-#include <sys/time.h>
 #include <sys/wait.h>
 #endif
 
@@ -205,7 +209,7 @@ SOK_T Connect_Remote (char *hostname, int port, FD_T aux)
             host_struct = gethostbyname (s5Host);
             if (host_struct == 0L)
             {
-                M_print ("[SOCKS] Can't find hostname: %s\n", s5Host);
+                M_print (i18n (596, "[SOCKS] Can't find hostname: %s\n"), s5Host);
                 return -1;
             }
             s5sin.sin_addr = *((struct in_addr *) host_struct->h_addr);
@@ -216,13 +220,13 @@ SOK_T Connect_Remote (char *hostname, int port, FD_T aux)
         s5Sok = socket (AF_INET, SOCK_STREAM, 0);       /* create the unconnected socket */
         if (s5Sok == -1)
         {
-            M_print ("[SOCKS] Socket creation failed\n");
+            M_print (i18n (597, "[SOCKS] Socket creation failed\n"));
             return -1;
         }
         conct = connect (s5Sok, (struct sockaddr *) &s5sin, sizeof (s5sin));
         if (conct == -1)        /* did we connect ? */
         {
-            M_print ("[SOCKS] Connection refused\n");
+            M_print (i18n (598, "[SOCKS] Connection refused\n"));
             return -1;
         }
         buf[0] = 5;             /* protocol version */
@@ -237,7 +241,7 @@ SOK_T Connect_Remote (char *hostname, int port, FD_T aux)
         {
             if (res != 2 || buf[0] != 5 || buf[1] != 2) /* username/password authentication */
             {
-                M_print ("[SOCKS] Authentication method incorrect\n");
+                M_print (i18n (599, "[SOCKS] Authentication method incorrect\n"));
                 close (s5Sok);
                 return -1;
             }
@@ -250,7 +254,7 @@ SOK_T Connect_Remote (char *hostname, int port, FD_T aux)
             res = recv (s5Sok, buf, 2, 0);
             if (res != 2 || buf[0] != 1 || buf[1] != 0)
             {
-                M_print ("[SOCKS] Authorization failure\n");
+                M_print (i18n (600, "[SOCKS] Authorization failure\n"));
                 close (s5Sok);
                 return -1;
             }
@@ -259,7 +263,7 @@ SOK_T Connect_Remote (char *hostname, int port, FD_T aux)
         {
             if (res != 2 || buf[0] != 5 || buf[1] != 0) /* no authentication required */
             {
-                M_print ("[SOCKS] Authentication method incorrect\n");
+                M_print (i18n (599, "[SOCKS] Authentication method incorrect\n"));
                 close (s5Sok);
                 return -1;
             }
@@ -278,7 +282,7 @@ SOK_T Connect_Remote (char *hostname, int port, FD_T aux)
         res = recv (s5Sok, buf, 10, 0);
         if (res != 10 || buf[0] != 5 || buf[1] != 0)
         {
-            M_print ("[SOCKS] General SOCKS server failure\n");
+            M_print (i18n (601, "[SOCKS] General SOCKS server failure\n"));
             close (s5Sok);
             return -1;
         }
@@ -320,9 +324,6 @@ SOK_T Connect_Remote (char *hostname, int port, FD_T aux)
         if (Verbose)
         {
             M_fdprint (aux, i18n (54, " Conection Refused on port %d at %s\n"), port, hostname);
-#ifdef FUNNY_MSGS
-            M_fdprint (aux, " D'oh!\n");
-#endif
             perror ("connect");
         }
         return -1;
@@ -394,9 +395,6 @@ int Connect_Remote_Old (char *hostname, int port, FD_T aux)
         if (Verbose)
         {
             M_fdprint (aux, i18n (54, " Conection Refused on port %d at %s\n"), port, hostname);
-#ifdef FUNNY_MSGS
-            M_fdprint (aux, " D'oh!\n");
-#endif
             perror ("connect");
         }
         return 0;
@@ -431,10 +429,10 @@ void Handle_Server_Response (SOK_T sok)
 //#if 0      
     if (Verbose)
     {
-        M_print ("Cmd : %04X\t", Chars_2_Word (pak.head.cmd));
-        M_print ("Ver : %04X\t", Chars_2_Word (pak.head.ver));
-        M_print ("Seq : %08X\t", Chars_2_DW (pak.head.seq));
-        M_print ("Ses : %08X\n", Chars_2_DW (pak.head.session));
+        M_print (i18n (602, "Cmd: %04X\t"), Chars_2_Word (pak.head.cmd));
+        M_print (i18n (603, "Ver: %04X\t"), Chars_2_Word (pak.head.ver));
+        M_print (i18n (604, "Seq: %08X\t"), Chars_2_DW (pak.head.seq));
+        M_print (i18n (605, "Ses: %08X\n"), Chars_2_DW (pak.head.session));
     }
 //#endif
 //    if ( pak.head.cmd != SRV_BAD_PASS ) {
@@ -453,7 +451,7 @@ void Handle_Server_Response (SOK_T sok)
         if (Verbose)
         {
             R_undraw ();
-            M_print ("Got a bad session ID %08X with CMD %04X ignored.\n",
+            M_print (i18n (606, "Got a bad session ID %08X with CMD %04X ignored.\n"),
                      Chars_2_DW (pak.head.session), Chars_2_Word (pak.head.cmd));
             R_redraw ();
         }
@@ -544,10 +542,9 @@ void Idle_Check (SOK_T sok)
     {
         icq_change_status (sok, STATUS_ONLINE);
         R_undraw ();
-        M_print (i18n (64, "Auto-Changed status to "));
-        Print_Status (Current_Status);
-        M_print (" ");
         Time_Stamp ();
+        M_print (" %s ", i18n (64, "Auto-Changed status to"));
+        Print_Status (Current_Status);
         M_print ("\n");
         R_redraw ();
         idle_flag = 0;
@@ -557,10 +554,9 @@ void Idle_Check (SOK_T sok)
     {
         icq_change_status (sok, STATUS_NA);
         R_undraw ();
-        M_print (i18n (64, "Auto-Changed status to "));
-        Print_Status (Current_Status);
-        M_print (" ");
         Time_Stamp ();
+        M_print (" %s ", i18n (64, "Auto-Changed status to"));
+        Print_Status (Current_Status);
         M_print ("\n");
         R_redraw ();
         return;
@@ -573,10 +569,9 @@ void Idle_Check (SOK_T sok)
     {
         icq_change_status (sok, STATUS_AWAY);
         R_undraw ();
-        M_print (i18n (64, "Auto-Changed status to "));
-        Print_Status (Current_Status);
-        M_print (" ");
         Time_Stamp ();
+        M_print (" %s ", i18n (64, "Auto-Changed status to"));
+        Print_Status (Current_Status);
         M_print ("\n");
         R_redraw ();
         idle_flag = 1;
@@ -586,11 +581,11 @@ void Idle_Check (SOK_T sok)
 
 void Usage ()
 {
-    M_print ("Usage: micq [-v|-V] [-f|-F <rc-file>] [-l|-L <logfile>] [-?|-h]\n");
-    M_print ("        -v   Turn on verbose Mode (useful for Debugging only)\n");
-    M_print ("        -f   specifies an alternate Config File (default: ~/.micqrc)\n");
-    M_print ("        -l   specifies an alternate LogFile\n");
-    M_print ("        -?   gives this help screen\n\n");
+    M_print (i18n (607, "Usage: micq [-v|-V] [-f|-F <rc-file>] [-l|-L <logfile>] [-?|-h]\n"));
+    M_print (i18n (608, "        -v   Turn on verbose Mode (useful for Debugging only)\n"));
+    M_print (i18n (609, "        -f   specifies an alternate Config File (default: ~/.micqrc)\n"));
+    M_print (i18n (610, "        -l   specifies an alternate LogFile\n"));
+    M_print (i18n (611, "        -?   gives this help screen\n\n"));
     exit (0);
 }
 
@@ -609,22 +604,20 @@ int main (int argc, char *argv[])
     WSADATA wsaData;
 #endif
 
-    i = i18nOpen (NULL);
+    i = i18nOpen ("!");
 
     setbuf (stdout, NULL);      /* Don't buffer stdout */
     M_print (BuildVersion ());
 
-#ifdef FUNNY_MSGS
-    M_print ("No Mirabilis client was maimed, hacked, tortured, sodomized or otherwise harmed  in the making of this utility.\n");
-#else
-    M_print ("This program was made without any help from Mirabilis or their consent.\n");
-    M_print ("No reverse engineering or decompilation of any Mirabilis code took place to make this program.\n");
-#endif
+    M_print (i18n (612, "This program was made without any help from Mirabilis or their consent.\n"));
+    M_print (i18n (613, "No reverse engineering or decompilation of any Mirabilis code took place to make this program.\n"));
 
-    if (i)
-        M_print (i18n (0, "Successfully loaded translations (%d entries). No version.\n"), i);
-    else
+    if (i == -1)
         M_print ("Couldn't load internationalization.\n");
+    else if (i)
+        M_print (i18n (81, "Successfully loaded en translation (%d entries).\n"), i);
+    else
+        M_print ("No internationalization requested.\n");
 
     /* and now we save the time that Micq was started, so that uptime will be
        able to appear semi intelligent.                                                                          */
@@ -648,12 +641,12 @@ int main (int argc, char *argv[])
             {
                 i++;            /* skip the argument to f */
                 Set_rcfile (argv[i]);
-                M_print ("The config file for this session is \"%s\"\n", argv[i]);
+                M_print (i18n (614, "The config file for this session is \"%s\"\n"), argv[i]);
             }
             else if ((argv[i][1] == 'l') || (argv[i][1] == 'L'))
             {
                 i++;
-                M_print ("The logging directory for this session is \"%s\"\n",
+                M_print (i18n (615, "The logging directory for this session is \"%s\"\n"),
                          Set_Log_Dir (argv[i]));
             }
             else if ((argv[i][1] == '?') || (argv[i][1] == 'h'))
@@ -668,7 +661,7 @@ int main (int argc, char *argv[])
     srand (time (NULL));
     if (!strcmp (passwd, ""))
     {
-        M_print (i18n (63, "Enter password : "));
+        M_print ("%s ", i18n (63, "Enter password:"));
         Echo_Off ();
         M_fdnreadln (STDIN, passwd, sizeof (passwd));
         Echo_On ();
@@ -677,7 +670,7 @@ int main (int argc, char *argv[])
 
 #ifdef __BEOS__
     Be_Start ();
-    M_print ("Started BeOS InputThread\n\r");
+    M_print (i18n (616, "Started BeOS InputThread\n\r"));
 #endif
 
     Initialize_Msg_Queue ();
@@ -688,11 +681,8 @@ int main (int argc, char *argv[])
     i = WSAStartup (0x0101, &wsaData);
     if (i != 0)
     {
-#ifdef FUNNY_MSGS
-        perror ("Windows Sockets broken blame Bill -");
-#else
-        perror ("Sorry, can't initialize Windows Sockets...");
-#endif
+/* FUNNY: "Windows Sockets broken blame Bill -" */
+        perror (i18n (###, "Sorry, can't initialize Windows Sockets..."));
         exit (1);
     }
 #endif
@@ -720,14 +710,10 @@ int main (int argc, char *argv[])
     for (; !Quit;)
     {
         Idle_Check (sok);
-#ifdef UNIX
-        M_set_timeout (2, 500000);
+#if _WIN32 || defined(__BEOS__)
+        M_set_timeout (0, 100000);
 #else
-        M_set_timeout (0, 100000);
-#endif
-
-#ifdef __BEOS__
-        M_set_timeout (0, 100000);
+        M_set_timeout (2, 500000);
 #endif
 
         M_select_init ();
@@ -743,10 +729,10 @@ int main (int argc, char *argv[])
 #if _WIN32
         if (_kbhit ())          /* sorry, this is a bit ugly...   [UH] */
 #else
-#ifndef __BEOS__
-        if (M_Is_Set (STDIN))
-#else
+#ifdef __BEOS__
         if (Be_TextReady ())
+#else
+        if (M_Is_Set (STDIN))
 #endif
 #endif
         {
@@ -765,7 +751,7 @@ int main (int argc, char *argv[])
         {
             Do_Resend (sok);
         }
-#ifdef UNIX
+#if HAVE_FORK
         while (waitpid (-1, NULL, WNOHANG) > 0);        /* clean up child processes */
 #endif
     }
