@@ -1,5 +1,8 @@
+/* $Id: network.c,v 1.7 2001/05/22 23:42:07 kuhlmann Exp $ */
+
 #include "micq.h"
 #include "util_ui.h"
+#include "network.h"
 #include <assert.h>
 
 static UWORD recv_packs[MAX_SEQ_DEPTH];
@@ -22,7 +25,7 @@ BOOL Is_Repeat_Packet (UWORD this_seq)
             if (Verbose)
             {
                 R_undraw ();
-                M_print ("\nDoubled packet %04X\n", this_seq);
+                M_print (i18n (623, "\nDoubled packet %04X\n"), this_seq);
                 R_redraw ();
             }
             return TRUE;
