@@ -1,3 +1,5 @@
+/* $Id: sendmsg.c,v 1.14 2001/06/17 21:56:27 kuhlmann Exp $ */
+
 /*
 Send Message Function for ICQ... 
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -5,7 +7,6 @@ Author : zed@mentasm.com
 */
 #include <stdlib.h>
 #include <stdio.h>
-#include <time.h>
 #ifdef _WIN32
 #include <winsock2.h>
 #else
@@ -19,6 +20,9 @@ Author : zed@mentasm.com
 #include <limits.h>
 #include "micq.h"
 #include "util_ui.h"
+#include "sendmsg.h"
+#include "util.h"
+#include "conv.h"
 
 /*unsigned int next_resend;*/
 UDWORD Packets_Sent = 0;
@@ -27,6 +31,12 @@ UDWORD Packets_Recv = 0;
 UDWORD our_session;
 
 static size_t SOCKWRITE_LOW (SOK_T sok, void *ptr, size_t len);
+static void Fill_Header (net_icq_pak * pak, UWORD cmd);
+static void info_req_99 (SOK_T sok, UDWORD uin);
+static void info_req_old (SOK_T sok, UDWORD uin);
+static void Gen_Checksum (UBYTE * buf, UDWORD len);
+static UDWORD Scramble_cc (UDWORD cc);
+static void Wrinkle (void *buf, size_t len);
 
 /* Historical */
 void Initialize_Msg_Queue ()
@@ -56,9 +66,10 @@ void Do_Resend (SOK_T sok)
             if (Verbose)
             {
                 R_undraw ();
-                M_print ("\nResending message with SEQ num %04x.\tCMD ", (queued_msg->seq >> 16));
+                M_print ("\n");
+                M_print (i18n (624, "Resending message with SEQ num %04X CMD "), (queued_msg->seq >> 16));
                 Print_CMD (Chars_2_Word (&queued_msg->body[CMD_OFFSET]));
-                M_print ("(Attempt #%d.)", queued_msg->attempts);
+                M_print (i18n (625, "(Attempt #%d.)"), queued_msg->attempts);
                 M_print ("%d\n", queued_msg->len);
                 R_redraw ();
             }
@@ -83,9 +94,10 @@ void Do_Resend (SOK_T sok)
             if (CMD_SENDM == Chars_2_Word (pak.head.cmd))
             {
                 s_mesg = (SIMPLE_MESSAGE_PTR) pak.data;
-                M_print ("\nDiscarding message to ");
+                M_print ("\n");
+                M_print (i18n (626, "Discarding message to "));
                 Print_UIN_Name (Chars_2_DW (s_mesg->uin));
-                M_print (" after %d send attempts.  Message content:\n", queued_msg->attempts - 1);
+                M_print (i18n (627, " after %d send attempts.  Message content:\n"), queued_msg->attempts - 1);
 
                 type = Chars_2_Word (s_mesg->type);
                 data = s_mesg->len + 2;
@@ -95,33 +107,34 @@ void Do_Resend (SOK_T sok)
                     if (tmp != NULL)
                     {
                         *tmp = 0;
-                        char_conv ("cw", data);
+                        ConvUnixWin (data);
                         strcpy (url_desc, data);
                         tmp++;
                         data = tmp;
-                        char_conv ("cw", data);
+                        ConvUnixWin (data);
                         strcpy (url_data, data);
 
-                        M_print (" Description: " MESSCOL "%s" NOCOL "\n", url_desc);
-                        M_print (" URL        : " MESSCOL "%s" NOCOL " ", url_data);
+                        M_print (i18n (628, " Description: " COLMESS "%s" COLNONE "\n"), url_desc);
+                        M_print (i18n (629, " URL:         " COLMESS "%s" COLNONE), url_data);
                     }
                 }
                 else if (type == NORM_MESS || type == MRNORM_MESS)
                 {
-                    char_conv ("cw", data);
-                    M_print (MESSCOL "%s", data);
-                    M_print (NOCOL " ");
+                    ConvUnixWin (data);
+                    M_print (COLMESS "%s", data);
+                    M_print (COLNONE " ");
                 }
             }
             else
             {
-                M_print ("\nDiscarded a ");
+                M_print ("\n");
+                M_print (i18n (630, "Discarded a "));
                 Print_CMD (Chars_2_Word (pak.head.cmd));
-                M_print (" packet.");
+                M_print (i18n (631, " packet."));
                 if ((CMD_LOGIN == Chars_2_Word (pak.head.cmd))
                     || (CMD_KEEP_ALIVE == Chars_2_Word (pak.head.cmd)))
                 {
-                    M_print ("\n\aConnection unstable. Exiting....");
+                    M_print (i18n (632, "\n\aConnection unstable. Exiting...."));
                     Quit = TRUE;
                 }
             }
@@ -219,7 +232,7 @@ void Update_About (SOK_T sok, const char *about)
     Word_2_Chars (pak.data, META_INFO_ABOUT);
     Word_2_Chars (&pak.data[2], strlen (about) + 1);
     strcpy (&pak.data[4], about);
-    char_conv ("cw", &pak.data[4]);
+    ConvUnixWin (&pak.data[4]);
     pak.data[strlen (about) + 4] = 0;
     last_cmd[(seq_num - 1) & 0x3ff] = Chars_2_Word (pak.head.cmd);
     SOCKWRITE (sok, &(pak.head.ver), sizeof (pak.head) - 2 + 5 + strlen (about));
@@ -358,7 +371,7 @@ void snd_vis_list (int sok)
                 num_used++;
                 if (Contacts[i].invis_list)
                 {
-                    M_print ("ACK!!! %d\n", Contacts[i].uin);
+                    M_print (i18n (633, "ACK!!! %d\n"), Contacts[i].uin);
                 }
             }
         }
@@ -425,12 +438,7 @@ void Keep_Alive (int sok)
     if (Verbose)
     {
         R_undraw ();
-#ifdef FUNNY_MSGS
-        M_print ("\nIf you go to" MESSCOL " Z'Ha'Dum " NOCOL "you will die!!\n");
-        /* or if you don't send this packet */
-#else
-        M_print ("\nSend Keep_Alive packet to the server\n");
-#endif
+        M_print (i18n (634, "\nSend Keep_Alive packet to the server\n"));
         R_redraw ();
     }
 }
@@ -439,38 +447,22 @@ void Keep_Alive (int sok)
 The following data constitutes fair use for compatibility.
 *********************************************************/
 static const UBYTE table[] = {
-    0x59, 0x60, 0x37, 0x6B, 0x65, 0x62, 0x46, 0x48, 0x53, 0x61, 0x4C, 0x59,
-    0x60, 0x57, 0x5B, 0x3D,
-    0x5E, 0x34, 0x6D, 0x36, 0x50, 0x3F, 0x6F, 0x67, 0x53, 0x61, 0x4C, 0x59,
-    0x40, 0x47, 0x63, 0x39,
-    0x50, 0x5F, 0x5F, 0x3F, 0x6F, 0x47, 0x43, 0x69, 0x48, 0x33, 0x31, 0x64,
-    0x35, 0x5A, 0x4A, 0x42,
-    0x56, 0x40, 0x67, 0x53, 0x41, 0x07, 0x6C, 0x49, 0x58, 0x3B, 0x4D, 0x46,
-    0x68, 0x43, 0x69, 0x48,
-    0x33, 0x31, 0x44, 0x65, 0x62, 0x46, 0x48, 0x53, 0x41, 0x07, 0x6C, 0x69,
-    0x48, 0x33, 0x51, 0x54,
-    0x5D, 0x4E, 0x6C, 0x49, 0x38, 0x4B, 0x55, 0x4A, 0x62, 0x46, 0x48, 0x33,
-    0x51, 0x34, 0x6D, 0x36,
-    0x50, 0x5F, 0x5F, 0x5F, 0x3F, 0x6F, 0x47, 0x63, 0x59, 0x40, 0x67, 0x33,
-    0x31, 0x64, 0x35, 0x5A,
-    0x6A, 0x52, 0x6E, 0x3C, 0x51, 0x34, 0x6D, 0x36, 0x50, 0x5F, 0x5F, 0x3F,
-    0x4F, 0x37, 0x4B, 0x35,
-    0x5A, 0x4A, 0x62, 0x66, 0x58, 0x3B, 0x4D, 0x66, 0x58, 0x5B, 0x5D, 0x4E,
-    0x6C, 0x49, 0x58, 0x3B,
-    0x4D, 0x66, 0x58, 0x3B, 0x4D, 0x46, 0x48, 0x53, 0x61, 0x4C, 0x59, 0x40,
-    0x67, 0x33, 0x31, 0x64,
-    0x55, 0x6A, 0x32, 0x3E, 0x44, 0x45, 0x52, 0x6E, 0x3C, 0x31, 0x64, 0x55,
-    0x6A, 0x52, 0x4E, 0x6C,
-    0x69, 0x48, 0x53, 0x61, 0x4C, 0x39, 0x30, 0x6F, 0x47, 0x63, 0x59, 0x60,
-    0x57, 0x5B, 0x3D, 0x3E,
-    0x64, 0x35, 0x3A, 0x3A, 0x5A, 0x6A, 0x52, 0x4E, 0x6C, 0x69, 0x48, 0x53,
-    0x61, 0x6C, 0x49, 0x58,
-    0x3B, 0x4D, 0x46, 0x68, 0x63, 0x39, 0x50, 0x5F, 0x5F, 0x3F, 0x6F, 0x67,
-    0x53, 0x41, 0x25, 0x41,
-    0x3C, 0x51, 0x54, 0x3D, 0x5E, 0x54, 0x5D, 0x4E, 0x4C, 0x39, 0x50, 0x5F,
-    0x5F, 0x5F, 0x3F, 0x6F,
-    0x47, 0x43, 0x69, 0x48, 0x33, 0x51, 0x54, 0x5D, 0x6E, 0x3C, 0x31, 0x64,
-    0x35, 0x5A, 0x00, 0x00,
+    0x59, 0x60, 0x37, 0x6B, 0x65, 0x62, 0x46, 0x48, 0x53, 0x61, 0x4C, 0x59, 0x60, 0x57, 0x5B, 0x3D,
+    0x5E, 0x34, 0x6D, 0x36, 0x50, 0x3F, 0x6F, 0x67, 0x53, 0x61, 0x4C, 0x59, 0x40, 0x47, 0x63, 0x39,
+    0x50, 0x5F, 0x5F, 0x3F, 0x6F, 0x47, 0x43, 0x69, 0x48, 0x33, 0x31, 0x64, 0x35, 0x5A, 0x4A, 0x42,
+    0x56, 0x40, 0x67, 0x53, 0x41, 0x07, 0x6C, 0x49, 0x58, 0x3B, 0x4D, 0x46, 0x68, 0x43, 0x69, 0x48,
+    0x33, 0x31, 0x44, 0x65, 0x62, 0x46, 0x48, 0x53, 0x41, 0x07, 0x6C, 0x69, 0x48, 0x33, 0x51, 0x54,
+    0x5D, 0x4E, 0x6C, 0x49, 0x38, 0x4B, 0x55, 0x4A, 0x62, 0x46, 0x48, 0x33, 0x51, 0x34, 0x6D, 0x36,
+    0x50, 0x5F, 0x5F, 0x5F, 0x3F, 0x6F, 0x47, 0x63, 0x59, 0x40, 0x67, 0x33, 0x31, 0x64, 0x35, 0x5A,
+    0x6A, 0x52, 0x6E, 0x3C, 0x51, 0x34, 0x6D, 0x36, 0x50, 0x5F, 0x5F, 0x3F, 0x4F, 0x37, 0x4B, 0x35,
+    0x5A, 0x4A, 0x62, 0x66, 0x58, 0x3B, 0x4D, 0x66, 0x58, 0x5B, 0x5D, 0x4E, 0x6C, 0x49, 0x58, 0x3B,
+    0x4D, 0x66, 0x58, 0x3B, 0x4D, 0x46, 0x48, 0x53, 0x61, 0x4C, 0x59, 0x40, 0x67, 0x33, 0x31, 0x64,
+    0x55, 0x6A, 0x32, 0x3E, 0x44, 0x45, 0x52, 0x6E, 0x3C, 0x31, 0x64, 0x55, 0x6A, 0x52, 0x4E, 0x6C,
+    0x69, 0x48, 0x53, 0x61, 0x4C, 0x39, 0x30, 0x6F, 0x47, 0x63, 0x59, 0x60, 0x57, 0x5B, 0x3D, 0x3E,
+    0x64, 0x35, 0x3A, 0x3A, 0x5A, 0x6A, 0x52, 0x4E, 0x6C, 0x69, 0x48, 0x53, 0x61, 0x6C, 0x49, 0x58,
+    0x3B, 0x4D, 0x46, 0x68, 0x63, 0x39, 0x50, 0x5F, 0x5F, 0x3F, 0x6F, 0x67, 0x53, 0x41, 0x25, 0x41,
+    0x3C, 0x51, 0x54, 0x3D, 0x5E, 0x54, 0x5D, 0x4E, 0x4C, 0x39, 0x50, 0x5F, 0x5F, 0x5F, 0x3F, 0x6F,
+    0x47, 0x43, 0x69, 0x48, 0x33, 0x51, 0x54, 0x5D, 0x6E, 0x3C, 0x31, 0x64, 0x35, 0x5A, 0x00, 0x00,
 };
 
 /***************************************************
@@ -488,7 +480,7 @@ void icq_sendmsg (SOK_T sok, UDWORD uin, char *text, UDWORD msg_type)
     else
         log_event (uin, LOG_MESS, "You sent instant message to %d\n%s\n", uin, text);
 
-    char_conv ("cw", text);
+    ConvUnixWin (text);
 
     len = strlen (text);
     Word_2_Chars (pak.head.ver, ICQ_VER);
@@ -916,62 +908,62 @@ void Update_More_User_Info (SOK_T sok, MORE_INFO_PTR user)
     size = 2;
     Word_2_Chars (pak.data + size, strlen (user->nick) + 1);
     size += 2;
-    char_conv ("cw", user->nick);
+    ConvUnixWin (user->nick);
     strcpy (pak.data + size, user->nick);
     size += strlen (user->nick) + 1;
     Word_2_Chars (pak.data + size, strlen (user->first) + 1);
     size += 2;
-    char_conv ("cw", user->first);
+    ConvUnixWin (user->first);
     strcpy (pak.data + size, user->first);
     size += strlen (user->first) + 1;
     Word_2_Chars (pak.data + size, strlen (user->last) + 1);
     size += 2;
-    char_conv ("cw", user->last);
+    ConvUnixWin (user->last);
     strcpy (pak.data + size, user->last);
     size += strlen (user->last) + 1;
     Word_2_Chars (pak.data + size, strlen (user->email) + 1);
     size += 2;
-    char_conv ("cw", user->email);
+    ConvUnixWin (user->email);
     strcpy (pak.data + size, user->email);
     size += strlen (user->email) + 1;
     Word_2_Chars (pak.data + size, strlen (user->email2) + 1);
     size += 2;
-    char_conv ("cw", user->email2);
+    ConvUnixWin (user->email2);
     strcpy (pak.data + size, user->email2);
     size += strlen (user->email2) + 1;
     Word_2_Chars (pak.data + size, strlen (user->email3) + 1);
     size += 2;
-    char_conv ("cw", user->email3);
+    ConvUnixWin (user->email3);
     strcpy (pak.data + size, user->email3);
     size += strlen (user->email3) + 1;
     Word_2_Chars (pak.data + size, strlen (user->city) + 1);
     size += 2;
-    char_conv ("cw", user->city);
+    ConvUnixWin (user->city);
     strcpy (pak.data + size, user->city);
     size += strlen (user->city) + 1;
     Word_2_Chars (pak.data + size, strlen (user->state) + 1);
     size += 2;
-    char_conv ("cw", user->state);
+    ConvUnixWin (user->state);
     strcpy (pak.data + size, user->state);
     size += strlen (user->state) + 1;
     Word_2_Chars (pak.data + size, strlen (user->phone) + 1);
     size += 2;
-    char_conv ("cw", user->phone);
+    ConvUnixWin (user->phone);
     strcpy (pak.data + size, user->phone);
     size += strlen (user->phone) + 1;
     Word_2_Chars (pak.data + size, strlen (user->fax) + 1);
     size += 2;
-    char_conv ("cw", user->fax);
+    ConvUnixWin (user->fax);
     strcpy (pak.data + size, user->fax);
     size += strlen (user->fax) + 1;
     Word_2_Chars (pak.data + size, strlen (user->street) + 1);
     size += 2;
-    char_conv ("cw", user->street);
+    ConvUnixWin (user->street);
     strcpy (pak.data + size, user->street);
     size += strlen (user->street) + 1;
     Word_2_Chars (pak.data + size, strlen (user->cellular) + 1);
     size += 2;
-    char_conv ("cw", user->cellular);
+    ConvUnixWin (user->cellular);
     strcpy (pak.data + size, user->cellular);
     size += strlen (user->cellular) + 1;
     DW_2_Chars (&pak.data[size], user->zip);
@@ -994,6 +986,103 @@ void Update_More_User_Info (SOK_T sok, MORE_INFO_PTR user)
     SOCKWRITE (sok, &(pak.head.ver), 4 + sizeof (pak.head) - 2);
 }
 
+void Search_WP (SOK_T sok, WP_PTR user)
+{
+    net_icq_pak pak;
+    int size;
+    Word_2_Chars (pak.head.ver, ICQ_VER);
+    Word_2_Chars (pak.head.cmd, CMD_META_USER);
+    Word_2_Chars (pak.head.seq, seq_num++);
+    DW_2_Chars (pak.head.UIN, UIN);
+
+    Word_2_Chars (pak.data, META_CMD_WP);
+    size = 2;
+    Word_2_Chars (pak.data + size, strlen (user->first) + 1);
+    size += 2;
+    ConvUnixWin (user->first);
+    strcpy (pak.data + size, user->first);
+    size += strlen (user->first) + 1;
+    Word_2_Chars (pak.data + size, strlen (user->last) + 1);
+    size += 2;
+    ConvUnixWin (user->last);
+    strcpy (pak.data + size, user->last);
+    size += strlen (user->last) + 1;
+    Word_2_Chars (pak.data + size, strlen (user->nick) + 1);
+    size += 2;
+    ConvUnixWin (user->nick);
+    strcpy (pak.data + size, user->nick);
+    size += strlen (user->nick) + 1;
+    Word_2_Chars (pak.data + size, strlen (user->email) + 1);
+    size += 2;
+    ConvUnixWin (user->email);
+    strcpy (pak.data + size, user->email);
+    size += strlen (user->email) + 1;
+    Word_2_Chars (pak.data + size, user->minage);
+    size += 2;
+    Word_2_Chars (pak.data + size, user->maxage);
+    size += 2;
+    pak.data[size] = user->sex;
+    size += 1;
+    Word_2_Chars (pak.data+size,user->language);  
+    size += 1;
+    Word_2_Chars (pak.data + size, strlen (user->city) + 1);
+    size += 2;
+    ConvUnixWin (user->city);
+    strcpy (pak.data + size, user->city);
+    size += strlen (user->city) + 1;
+    Word_2_Chars (pak.data + size, strlen (user->state) + 1);
+    size += 2;
+    ConvUnixWin (user->state);
+    strcpy (pak.data + size, user->state);
+    size += strlen (user->state) + 1;
+    Word_2_Chars (pak.data + size, user->country);
+    size += 2;
+    Word_2_Chars (pak.data + size, strlen (user->company) + 1);
+    size += 2;
+    ConvUnixWin (user->company);
+    strcpy (pak.data + size, user->company);
+    size += strlen (user->company) + 1;
+    Word_2_Chars (pak.data + size, strlen (user->department) + 1);
+    size += 2;
+    ConvUnixWin (user->department);
+    strcpy (pak.data + size, user->department);
+    size += strlen (user->department) + 1;
+    Word_2_Chars (pak.data + size, strlen (user->position) + 1);
+    size += 2;
+    ConvUnixWin (user->position);
+    strcpy (pak.data + size, user->position);
+    size += strlen (user->position) + 1;
+/*  Now it gets REALLY shakey, as I don't know even what
+    these particular bits of information are.
+    If you know, fill them in. Pretty sure they are
+    interests, organizations, homepage and something else
+    but not sure what order. -KK */
+    Word_2_Chars (pak.data+size, 0x00);
+    size += 1;
+    Word_2_Chars (pak.data+size, 0x0000);
+    size += 2;
+    Word_2_Chars (pak.data+size, 0x01);
+    size += 1;
+    DW_2_Chars (pak.data+size, 0x00000000);
+    size += 4;
+    Word_2_Chars (pak.data+size, 0x01);
+    size += 1;
+    DW_2_Chars (pak.data+size, 0x00000000);
+    size += 4;
+    Word_2_Chars (pak.data+size, 0x01);
+    size += 1;
+    DW_2_Chars (pak.data+size, 0x00000000);
+    size += 4;
+    Word_2_Chars (pak.data+size, 0x01);
+    size += 1;
+    Word_2_Chars (pak.data+size, 0x0000);
+    size += 2;
+    pak.data[size] = user->online;
+    size+=1;
+    last_cmd[(seq_num - 1) & 0x3ff] = Chars_2_Word (pak.head.cmd);
+    SOCKWRITE (sok, &(pak.head.ver), size + sizeof (pak.head) - 2);
+}
+
 void icq_sendurl (SOK_T sok, UDWORD uin, char *description, char *url)
 {
     char buf[450];
@@ -1137,7 +1226,6 @@ size_t SOCKWRITE (SOK_T sok, void *ptr, size_t len)
             next_resend = msg_to_queue->exp_time;
         }
     }
-
     return SOCKWRITE_LOW (sok, ptr, len);
 }
 
