@@ -1,3 +1,5 @@
+/* $Id: util.c,v 1.13 2001/06/17 21:56:28 kuhlmann Exp $ */
+
 /*********************************************
 **********************************************
 This is a file of general utility functions useful
@@ -17,6 +19,8 @@ Changes :
 **********************************************
 **********************************************/
 #include "micq.h"
+#include "util.h"
+#include "sendmsg.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -24,7 +28,6 @@ Changes :
 #include <string.h>
 #include <ctype.h>
 #include <errno.h>
-#include <time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -34,17 +37,18 @@ Changes :
 #define S_IRUSR          _S_IREAD
 #define S_IWUSR          _S_IWRITE
 #else
-#include <sys/time.h>
 #include <netinet/in.h>
 #ifndef __BEOS__
 #include <arpa/inet.h>
 #endif
 #endif
-#ifdef UNIX
+#if HAVE_UNISTD_H
 #include <unistd.h>
-#include <termios.h>
-#include "mreadline.h"
 #endif
+#if HAVE_TERMIOS_H
+#include <termios.h>
+#endif
+#include "mreadline.h"
 
 #ifdef _WIN32
 typedef struct
@@ -103,43 +107,43 @@ void Print_CMD (UWORD cmd)
     switch (cmd)
     {
         case CMD_KEEP_ALIVE:
-            M_print ("Keep Alive");
+            M_print (i18n (743, "Keep Alive"));
             break;
         case CMD_KEEP_ALIVE2:
-            M_print ("Secondary Keep Alive");
+            M_print (i18n (744, "Secondary Keep Alive"));
             break;
         case CMD_CONT_LIST:
-            M_print ("Contact List");
+            M_print (i18n (745, "Contact List"));
             break;
         case CMD_INVIS_LIST:
-            M_print ("Invisible List");
+            M_print (i18n (746, "Invisible List"));
             break;
         case CMD_VIS_LIST:
-            M_print ("Visible List");
+            M_print (i18n (747, "Visible List"));
             break;
         case CMD_RAND_SEARCH:
-            M_print ("Random Search");
+            M_print (i18n (748, "Random Search"));
             break;
         case CMD_RAND_SET:
-            M_print ("Set Random");
+            M_print (i18n (749, "Set Random"));
             break;
         case CMD_ACK_MESSAGES:
-            M_print ("Delete Server Messages");
+            M_print (i18n (750, "Delete Server Messages"));
             break;
         case CMD_LOGIN_1:
-            M_print ("Finish Login");
+            M_print (i18n (751, "Finish Login"));
             break;
         case CMD_LOGIN:
-            M_print ("Login");
+            M_print (i18n (752, "Login"));
             break;
         case CMD_SENDM:
-            M_print ("Send Message");
+            M_print (i18n (753, "Send Message"));
             break;
         case CMD_INFO_REQ:
-            M_print ("Info Request");
+            M_print (i18n (754, "Info Request"));
             break;
         case CMD_EXT_INFO_REQ:
-            M_print ("Extended Info Request");
+            M_print (i18n (755, "Extended Info Request"));
             break;
         default:
             M_print ("%04X", cmd);
@@ -276,11 +280,11 @@ int Print_UIN_Name (UDWORD uin)
     {
         if (Contacts[i].uin == uin)
         {
-            M_print (CONTACTCOL "%s" NOCOL, Contacts[i].nick);
+            M_print (COLCONTACT "%s" COLNONE, Contacts[i].nick);
             return i;
         }
     }
-    M_print (CLIENTCOL "%lu" NOCOL, uin);
+    M_print (COLCLIENT "%lu" COLNONE, uin);
     return -1;
 }
 
@@ -296,12 +300,12 @@ int Print_UIN_Name_10 (UDWORD uin)
     {
         if (Contacts[i].uin == uin)
         {
-            M_print (CONTACTCOL "%10s" NOCOL, Contacts[i].nick);
+            M_print (COLCONTACT "%10s" COLNONE, Contacts[i].nick);
             return i;
         }
     }
 
-    M_print (CLIENTCOL "%8lu" NOCOL, uin);
+    M_print (COLCLIENT "%10lu" COLNONE, uin);
     return -1;
 }
 
@@ -313,19 +317,10 @@ CONTACT_PTR UIN2Contact (UDWORD uin)
     int i;
 
     for (i = 0; i < Num_Contacts; i++)
-    {
         if (Contacts[i].uin == uin)
-            break;
-    }
+            return &Contacts[i];
 
-    if (i == Num_Contacts)
-    {
-        return (CONTACT_PTR) NULL;
-    }
-    else
-    {
-        return &Contacts[i];
-    }
+    return (CONTACT_PTR) NULL;
 }
 
 /*********************************************
@@ -389,31 +384,27 @@ void Init_New_User (void)
     i = WSAStartup (0x0101, &wsaData);
     if (i != 0)
     {
-#ifdef FUNNY_MSGS
-        perror ("Windows Sockets broken blame Bill -");
-#else
-        perror ("Sorry, can't initialize Windows Sockets...");
-#endif
+        perror (i18n (###, "Sorry, can't initialize Windows Sockets..."));
         exit (1);
     }
 #endif
-    M_print ("\nCreating Connection...\n");
+    M_print (i18n (756, "\nCreating Connection...\n"));
     sok = Connect_Remote (server, remote_port, STDERR);
     if ((sok == -1) || (sok == 0))
     {
-        M_print ("Couldn't establish connection\n");
+        M_print (i18n (757, "Couldn't establish connection\n"));
         exit (1);
     }
-    M_print ("Sending Request...\n");
+    M_print (i18n (758, "Sending Request...\n"));
     reg_new_user (sok, passwd);
     for (;;)
     {
-#ifdef UNIX
-        tv.tv_sec = 3;
-        tv.tv_usec = 500000;
-#else
+#ifdef _WIN32
         tv.tv_sec = 0;
         tv.tv_usec = 100000;
+#else
+        tv.tv_sec = 3;
+        tv.tv_usec = 500000;
 #endif
 
         FD_ZERO (&readfds);
@@ -421,14 +412,14 @@ void Init_New_User (void)
 
         /* don't care about writefds and exceptfds: */
         select (sok + 1, &readfds, NULL, NULL, &tv);
-        M_print ("Waiting for response....\n");
+        M_print (i18n (759, "Waiting for response....\n"));
         if (FD_ISSET (sok, &readfds))
         {
             s = SOCKREAD (sok, &pak.head.ver, sizeof (pak) - 2);
             if (Chars_2_Word (pak.head.cmd) == SRV_NEW_UIN)
             {
                 UIN = Chars_2_DW (pak.head.UIN);
-                M_print ("\nYour new UIN is %s%ld%s!\n", SERVCOL, UIN, NOCOL);
+                M_print (i18n (760, "\nYour new UIN is %s%ld%s!\n"), COLSERV, UIN, COLNONE);
                 return;
             }
             else
@@ -460,12 +451,12 @@ void Print_IP (UDWORD uin)
             }
             else
             {
-                M_print ("unknown");
+                M_print (i18n (761, "unknown"));
             }
             return;
         }
     }
-    M_print ("unknown");
+    M_print (i18n (761, "unknown"));
 }
 
 /************************************************
@@ -567,7 +558,6 @@ const char *Set_Log_Dir (const char *newpath)
         path = "PROGDIR:";
 #endif
 
-#ifdef UNIX
         home = getenv ("HOME");
         if (home || !path)
         {
@@ -578,7 +568,6 @@ const char *Set_Log_Dir (const char *newpath)
             if (path[strlen (path) - 1] != '/')
                 strcat (path, "/");
         }
-#endif
 
         Log_Dir = path;
         return path;
@@ -676,7 +665,7 @@ int log_event (UDWORD uin, int type, char *str, ...)
             strcpy (symbuf, buffer);
             sprintf (&buffer[strlen (buffer)], "%ld.log", uin);
 
-#ifdef UNIX
+#if HAVE_SYMLINK
             if (NULL != UIN2nick (uin))
             {
                 sprintf (&symbuf[strlen (symbuf)], "%s.log", UIN2nick (uin));
@@ -693,9 +682,9 @@ int log_event (UDWORD uin, int type, char *str, ...)
         return (-1);
     }
 /*     if ( ! strcasecmp(UIN2nick(uin),"Unknow UIN"))
-         fprintf(msgfd, "\n%-24.24s %s %ld\n%s\n", ctime(&timeval), desc, uin, msg);
+         fprintf (msgfd, "\n%-24.24s %s %ld\n%s\n", ctime(&timeval), desc, uin, msg);
      else
-         fprintf(msgfd, "\n%-24.24s %s %s\n%s\n", ctime(&timeval), desc, UIN2nick(uin), msg);*/
+         fprintf (msgfd, "\n%-24.24s %s %s\n%s\n", ctime(&timeval), desc, UIN2nick(uin), msg);*/
 
     if (strlen (buf))
     {
@@ -711,7 +700,7 @@ int log_event (UDWORD uin, int type, char *str, ...)
     va_end (args);
 
     fclose (msgfd);
-#ifdef UNIX
+#if HAVE_CHMOD
     chmod (buffer, 0600);
 #endif
     return (0);
@@ -722,18 +711,10 @@ int log_event (UDWORD uin, int type, char *str, ...)
 **************************************************/
 void clrscr (void)
 {
-#ifdef UNIX
-    system ("clear");
+#ifdef ANSI_COLOR
+    printf ("\x1b[H\x1b[J");
 #else
-#ifdef _WIN32
-    system ("cls");
-#else
-    int x;
-    char newline = '\n';
-
-    for (x = 0; x <= 25; x++)
-        M_print ("%c", newline);
-#endif
+    M_print ("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n");
 #endif
 }
 
@@ -751,7 +732,7 @@ void Hex_Dump (void *buffer, size_t len)
     assert (len > 0);
     if ((len > 1000))
     {
-        M_print ("Ack!!!!!!  %d\a\n", len);
+        M_print (i18n (762, "Ack!!!!!!  %d\a\n"), len);
         return;
     }
     for (i = 0; i < len; i++)
